@@ -151,3 +151,61 @@ def get_boundary_mask_from_list(radar: pyart.core.Radar, x_points: List[int], y_
         boundary_list_of_lists.append(array_to_list(boundary, radar.ngates))
 
     return boundary_list_of_lists
+
+def run_boundary_on_ray(x_points: List, y_points: List, nBoundaryPoints: int, radar_origin_latitude: float, radar_origin_longitude: float, radar_origin_altitude: float,
+        boundary_origin_latitude: float, boundary_origin_longitude: float, boundary_origin_altitude: float, nGates: int, gateSize: float, distanceToCellNInMeters: float,
+        azimuth: float, radar_scan_mode: int, radar_type: int, boundary: List) -> List:
+
+    boundary = list_to_array(boundary, ctypes.c_bool)
+
+    aliases["get_boundary_mask"].restype = None
+
+    # define the boundary mask function's argument types
+    aliases["get_boundary_mask"].argtypes = (
+        ctypes.POINTER(ctypes.c_long),
+        ctypes.POINTER(ctypes.c_long),
+        ctypes.c_int,
+        ctypes.c_float,
+        ctypes.c_float,
+        ctypes.c_float,
+        ctypes.c_float,
+        ctypes.c_float,
+        ctypes.c_float,
+        ctypes.c_float,
+        ctypes.c_int,
+        ctypes.c_float,
+        ctypes.c_float,
+        ctypes.c_float,
+        ctypes.c_int,
+        ctypes.c_int,
+        ctypes.c_float,
+        ctypes.c_float,
+        ctypes.POINTER(ctypes.c_bool),
+        )
+
+    aliases["get_boundary_mask"](
+        list_to_array(x_points, ctypes.c_long),  # x_points
+        list_to_array(y_points, ctypes.c_long),  # y_points
+        nBoundaryPoints,  # npoints
+
+        ctypes.c_float(radar_origin_latitude),  # radar_origin_latitude
+        ctypes.c_float(radar_origin_longitude),  # radar_origin_longitude
+        ctypes.c_float(radar_origin_altitude),  # radar_origin_altitude
+
+        ctypes.c_float(0),  # boundary_origin_tilt
+        ctypes.c_float(boundary_origin_latitude),  # boundary_origin_latitude
+        ctypes.c_float(boundary_origin_longitude),  # boundary_origin_longitude
+        ctypes.c_float(boundary_origin_altitude),  # boundary_origin_altitude
+
+        ctypes.c_int(nGates),  # nGates
+        ctypes.c_float(gateSize),  # gateSize
+        ctypes.c_float(distanceToCellNInMeters),  # distanceToCellInMeters
+        ctypes.c_float(azimuth),  # azimuth
+        ctypes.c_int(radar_scan_mode),  # radar_scan_mode
+        ctypes.c_int(radar_type),  # radar_type
+        ctypes.c_float(0),  # tilt_angle
+        ctypes.c_float(0),  # rotation_angle ----- not used by code
+        boundary  # boundary_mask_out
+    )
+
+    return array_to_list(boundary, nGates)
